summaryrefslogtreecommitdiffstats
path: root/api/logic/FileSystem.cpp
diff options
context:
space:
mode:
authorTim Flynn <MC42@users.noreply.github.com>2017-01-16 16:42:22 -0500
committerPetr Mrázek <peterix@users.noreply.github.com>2017-01-16 22:42:22 +0100
commit98e17998fe4dd541143de3e1bbc4b267aadb383b (patch)
tree7be0da03813083e231647318e3175c800a0bf6eb /api/logic/FileSystem.cpp
parent944ff256b2d9e271632efacd6e8dd1ea542e869f (diff)
downloadMultiMC-98e17998fe4dd541143de3e1bbc4b267aadb383b.tar
MultiMC-98e17998fe4dd541143de3e1bbc4b267aadb383b.tar.gz
MultiMC-98e17998fe4dd541143de3e1bbc4b267aadb383b.tar.lz
MultiMC-98e17998fe4dd541143de3e1bbc4b267aadb383b.tar.xz
MultiMC-98e17998fe4dd541143de3e1bbc4b267aadb383b.zip
GH-1065 Normalize usage of directory vs folder
Diffstat (limited to 'api/logic/FileSystem.cpp')
-rw-r--r--api/logic/FileSystem.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/api/logic/FileSystem.cpp b/api/logic/FileSystem.cpp
index 67bafd28..b3115988 100644
--- a/api/logic/FileSystem.cpp
+++ b/api/logic/FileSystem.cpp
@@ -15,7 +15,7 @@ void ensureExists(const QDir &dir)
{
if (!QDir().mkpath(dir.absolutePath()))
{
- throw FileSystemException("Unable to create directory " + dir.dirName() + " (" +
+ throw FileSystemException("Unable to create folder " + dir.dirName() + " (" +
dir.absolutePath() + ")");
}
}
@@ -265,7 +265,7 @@ QString ResolveExecutable(QString path)
/**
* Normalize path
*
* Any paths inside the current directory will be normalized to relative paths (to current)
* Other paths will be made absolute
*/
QString NormalizePath(QString path)
@@ -324,7 +324,7 @@ QString DirNameFromString(QString string, QString inDir)
return dirName;
}
// Does the directory path contain any '!'? If yes, return true, otherwise false.
// (This is a problem for Java)
bool checkProblemticPathJava(QDir folder)
{
@@ -265,7 +265,7 @@ QString ResolveExecutable(QString path)
* Normalize path
*
- * Any paths inside the current directory will be normalized to relative paths (to current)
+ * Any paths inside the current folder will be normalized to relative paths (to current)
* Other paths will be made absolute
*/
@@ -324,7 +324,7 @@ QString DirNameFromString(QString string, QString inDir)
return dirName;
}
-// Does the directory path contain any '!'? If yes, return true, otherwise false.
+// Does the folder path contain any '!'? If yes, return true, otherwise false.
// (This is a problem for Java)
bool checkProblemticPathJava(QDir folder)